@@ -37,23 +37,24 @@ class Barry:
             currency = '€/KWH'
         return currency
 
-    def update_co2_emission(self):
+    def update_co2_emission(self, price_code):
         current_time = self.hour_rounder(datetime.utcnow().replace(microsecond=0)).isoformat() + 'Z'
         last_hour_date_time = self.hour_rounder(
-            (datetime.now() - timedelta(hours=1)).replace(microsecond=0)).isoformat() + 'Z'
+            (datetime.utcnow() - timedelta(hours=1)).replace(microsecond=0)).isoformat() + 'Z'
         headers = {
             'Authorization': 'Bearer ' + self.access_token,
             'Content-Type': 'application/json',
         }
-        data = '{ "jsonrpc": "2.0", "id": 0, "method": "co.getbarry.api.v1.OpenApiController.getHourlyCo2Emission", "params": [ "%s", "%s" ] }' % (
-            last_hour_date_time, current_time)
+        price_code = price_code.split('_')[-1]
+        data = '{ "jsonrpc": "2.0", "id": 0, "method": "co.getbarry.api.v1.OpenApiController.getHourlyCo2Intensity", "params": [ "%s", "%s", "%s" ] }' % (
+            price_code, last_hour_date_time, current_time)
         response = requests.post('https://jsonrpc.barry.energy/json-rpc', headers=headers, data=data)
         json_res = response.json()
         result = json_res.get('result')
         if result:
             result = result[0]
-            value = result['co2InKg']
-            return value, 'KG'
+            value = result['carbonIntensity']
+            return value, 'gCO2/kWh'
         else:
             return 'NA', '-'
 
